CryptoError

Enum CryptoError 

pub enum CryptoError {
Show 16 variants InvalidKey, InvalidAeadKeyLength { expected: usize, actual: usize, }, InvalidAeadNonceLength { expected: usize, actual: usize, }, InvalidCiphertextLength { minimum: usize, actual: usize, }, AeadEncrypt { backend: AeadBackend, kind: AeadFailureKind, }, AeadDecrypt { backend: AeadBackend, kind: AeadFailureKind, }, Signature { backend: SignatureBackend, operation: SignatureOperation, kind: SignatureFailureKind, }, KeyAgreementFailure { kind: KeyAgreementFailureKind, }, KemFailure { kind: KemFailureKind, }, KeyWrap { algorithm: KeyWrapAlgorithm, operation: KeyWrapOperation, kind: KeyWrapFailureKind, }, Kdf { algorithm: KdfAlgorithm, profile: KdfProfile, kind: KdfFailureKind, }, Hkdf { hash: HkdfHash, kind: HkdfFailureKind, }, Mac { hash: MacHash, kind: MacFailureKind, }, Rng { output: RngOutputKind, kind: RngFailureKind, }, ConstantTimeComparison { kind: ConstantTimeFailureKind, left_len: usize, right_len: usize, }, Unsupported,
}
Typed error taxonomy for all crypto operations in the workspace.

Variants



InvalidKey

Supplied key material was malformed or otherwise invalid.



InvalidAeadKeyLength

An AEAD key did not have the length the cipher requires.

Fields

expected: usize

Key length in bytes the cipher requires.

actual: usize

Key length in bytes that was supplied.



InvalidAeadNonceLength

An AEAD nonce did not have the length the cipher requires.

Fields

expected: usize

Nonce length in bytes the cipher requires.

actual: usize

Nonce length in bytes that was supplied.



InvalidCiphertextLength

A ciphertext was shorter than the minimum (tag) length.

Fields

minimum: usize

Minimum ciphertext length in bytes (the authentication tag length).

actual: usize

Ciphertext length in bytes that was supplied.



AeadEncrypt

AEAD encryption failed in the given backend for the given reason.

Fields

backend: AeadBackend

Backend lane in which the failure occurred.

kind: AeadFailureKind

Specific encryption failure cause.



AeadDecrypt

AEAD decryption failed in the given backend for the given reason.

Fields

backend: AeadBackend

Backend lane in which the failure occurred.

kind: AeadFailureKind

Specific decryption failure cause (includes authentication failure).



Signature

A signature operation failed in the given backend for the given reason.

Fields

backend: SignatureBackend

Backend lane in which the failure occurred.

operation: SignatureOperation

Operation (sign, verify, keygen, encode) that failed.

kind: SignatureFailureKind

Specific signature failure cause.



KeyAgreementFailure

A key agreement operation failed for the given reason.

Fields

kind: KeyAgreementFailureKind

Specific key-agreement failure cause.



KemFailure

A KEM (key encapsulation) operation failed for the given reason.

Fields

kind: KemFailureKind

Specific KEM failure cause.



KeyWrap

A key-wrap operation failed for the given algorithm and reason.

Fields

algorithm: KeyWrapAlgorithm

Key-wrap algorithm that failed.

operation: KeyWrapOperation

Operation (wrap or unwrap) that failed.

kind: KeyWrapFailureKind

Specific key-wrap failure cause.



Kdf

A password-based KDF operation failed for the given algorithm/profile.

Fields

algorithm: KdfAlgorithm

KDF algorithm that failed.

profile: KdfProfile

Cost profile in effect at the time of failure.

kind: KdfFailureKind

Specific KDF failure cause.



Hkdf

An HKDF operation failed for the given hash and reason.

Fields

hash: HkdfHash

Hash suite underlying the HKDF operation.

kind: HkdfFailureKind

Specific HKDF failure cause.



Mac

An HMAC operation failed for the given hash and reason.

Fields

hash: MacHash

Hash suite underlying the HMAC operation.

kind: MacFailureKind

Specific HMAC failure cause.



Rng

Secure random generation failed for the given output purpose.

Fields

output: RngOutputKind

Purpose the requested random bytes were being generated for.

kind: RngFailureKind

Specific RNG failure cause.



ConstantTimeComparison

A constant-time comparison did not match, with the two input lengths.

Fields

kind: ConstantTimeFailureKind

Specific comparison failure cause.

left_len: usize

Length in bytes of the left-hand input.

right_len: usize

Length in bytes of the right-hand input.



Unsupported

The requested operation is not supported.